function [ data ] = Kreisprozess( data )
%Auswertung

points=data.points;
R=data.R;
cv=data.cv;
cp=data.cp;
kap=data.kappa;
gam=data.gam; %Adiabatenexponent
T1=data.T1;
p1=data.p1;
V1=data.V1;

%%%%%%%%%%%% Einlesen der Varaiblenwerte
%1. Prozessschritt
%Variablenwert:
prozess1a_var=get(data.prozess1_ende,'string');
prozess1_var=str2num(prozess1a_var);
switch data.prozess1typ
    case 1 %isotherm
        [T2,p2,V2,dU1,dW1,dQ1,dS1,pv1,Vv1,Sv1,Tv1]=...
            isoth(T1,p1,V1,data.prozess1_var,prozess1_var,points);
    case 2 %isobar
        [T2,p2,V2,dU1,dW1,dQ1,dS1,pv1,Vv1,Sv1,Tv1]=...
            isob(T1,p1,V1,cp,data.prozess1_var,prozess1_var,points );
    case 3 %isochor
        [T2,p2,V2,dU1,dW1,dQ1,dS1,pv1,Vv1,Sv1,Tv1]=...
            isochor(T1,p1,V1,cv,data.prozess1_var,prozess1_var,points );
    case 4 %adiabatisch
        [T2,p2,V2,dU1,dW1,dQ1,dS1,pv1,Vv1,Sv1,Tv1]=...
            adiab(T1,p1,V1,gam,data.prozess1_var,prozess1_var,points );
    case 5 %polytrop
        [T2,p2,V2,dU1,dW1,dQ1,dS1,pv1,Vv1,Sv1,Tv1]=...
            poly(T1,p1,V1,kap,cv,data.prozess1_var,prozess1_var,points );
    otherwise
        error('du Typ, du');
end

%2. Prozessschritt
%Variablenwert:
prozess2_var=get(data.prozess2_ende,'string');
prozess2_var=str2num(prozess2_var);
switch data.prozess2typ
    case 1 %isotherm
        [T3,p3,V3,dU2,dW2,dQ2,dS2,pv2,Vv2,Sv2,Tv2]=...
            isoth(T2,p2,V2,data.prozess2_var,prozess2_var,points);
    case 2 %isobar
        [T3,p3,V3,dU2,dW2,dQ2,dS2,pv2,Vv2,Sv2,Tv2]=...
            isob(T2,p2,V2,cp,data.prozess2_var,prozess2_var,points );
    case 3 %isochor
        [T3,p3,V3,dU2,dW2,dQ2,dS2,pv2,Vv2,Sv2,Tv2]=...
            isochor(T2,p2,V2,cv,data.prozess2_var,prozess2_var,points );
    case 4 %adiabatisch
        [T3,p3,V3,dU2,dW2,dQ2,dS2,pv2,Vv2,Sv2,Tv2]=...
            adiab(T2,p2,V2,gam,data.prozess2_var,prozess2_var,points );
    case 5 %polytrop
        [T3,p3,V3,dU2,dW2,dQ2,dS2,pv2,Vv2,Sv2,Tv2]=...
            poly(T2,p2,V2,kap,cv,data.prozess2_var,prozess2_var,points );
    otherwise
        error('du Typ, du');
end


%%%%%%%%%%%%%%%%%%%%%%%%%%%% Berechnung des Zwischenpunktes
T5=T1;
p5=p1;
V5=V1;

fix3=0;
fix4=0;
weg1=false;
weg2=false;
switch data.prozess3typ
    case 1 %isotherm
           T4=T3;
           fix3=1;
           var3=T4;
    case 2 %isobar
           p4=p3;
           fix3=2;
           var3=p4;
    case 3 %isochor
           V4=V3;
           fix3=3;
           var3=V4;
    case 4 %adiabatisch
    case 5 %polytrop
    otherwise
        error('du Typ, du');
end

%4. Prozessschritt
switch data.prozess4typ
    case 1 %isotherm
           T4=T5;
           fix4=1;
           var4=T4;
    case 2 %isobar
           p4=p5;
           fix4=2;
           var4=p4;
    case 3 %isochor
           V4=V5;
           fix4=3;
           var4=V4;
    case 4 %adiabatisch
    case 5 %polytrop
    otherwise
        error('du Typ, du');
end

if(fix3~=0)
    switch data.prozess4typ
        case 1 %isotherm290
            %mit Startvolumen
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isoth(T5,p5,V5,fix3,var3,points);
        case 2 %isobar
            %mit Startvolumen
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isob(T5,p5,V5,cp,fix3,var3,points );
        case 3 %isochor
            %mit Startdruck
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isochor(T5,p5,V5,cv,fix3,var3,points );
        case 4 %adiabatisch
            %mit Startvolumen
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T5,p5,V5,gam,fix3,var3,points );
        case 5 %polytrop
            %mit Startvolumen
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T5,p5,V5,kap,cv,fix3,var3,points );    
    end
    weg2=true;
end

if(fix4~=0)
    switch data.prozess3typ
        case 1 %isotherm
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isoth(T3,p3,V3,fix4,var4,points);
        case 2 %isobar
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isob(T3,p3,V3,cp,fix4,var4,points );
        case 3 %isochor
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isochor(T3,p3,V3,cv,fix4,var4,points );
        case 4 %adiabatisch
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,fix4,var4,points );
        case 5 %polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,fix4,var4,points );
    end
    weg1=true;
end

if (weg2 && not(weg1))
    fix4=1;
    var4=T4a;
       switch data.prozess3typ
        case 1 %isotherm
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isoth(T3,p3,V3,2,p4a,points);
        case 2 %isobar
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isob(T3,p3,V3,cp,fix4,var4,points );
        case 3 %isochor
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                isochor(T3,p3,V3,cv,fix4,var4,points );
        case 4 %adiabatisch
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,fix4,var4,points );
        case 5 %polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,fix4,var4,points );
       end
    weg1=true;
end

if (weg1 && not(weg2))
    fix3=1;
    var3=T4;
    switch data.prozess4typ
        case 1 %isotherm
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isoth(T5,p5,V5,2,p4,points);
        case 2 %isobar
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isob(T5,p5,V5,cp,fix3,var3,points );
        case 3 %isochor
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                isochor(T5,p5,V5,cv,fix3,var3,points );
        case 4 %adiabatisch
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T5,p5,V5,gam,fix3,var3,points );
        case 5 %polytrop
            [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T5,p5,V5,kap,cv,fix3,var3,points );    
    end
    weg2=true;    
end

fehlerzero=1; %Uebergabe des Fehlerflags
if(not(weg1) && not(weg2))
    %Berechnung des Schnittpunkts
    hadiab=@(Vx,Vy,px) px.*(abs(Vx./Vy)).^gam; 
    hpolyt=@(Vx,Vy,px) px.*(abs(Vx./Vy)).^kap;
    if ((data.prozess3typ==4)&&(data.prozess4typ==5))
        %3 ... adiabatisch, 4 ... polytrop
        func=@(x) hadiab(V3,x,p3)-hpolyt(V5,x,p5);
        Vvek=sort([V3,V5]);
        Vvek=[Vvek(1)/data.umgebung,Vvek(2)*data.umgebung];
        try
        [V4best, fval, fehlerzero]=fzero(func,Vvek);
        catch errorcatch
            data.errorcatch=errorcatch;
            fehlerzero=-0.5;
            V4best=(V3+V5)/2;
        end
        %Berechnung der Werte fuer den Schnittpunkt
        [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,3,V4best,points );
        [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T5,p5,V5,kap,cv,3,V4best,points ); 
        weg1=true;
        weg2=true;
    end
    if ((data.prozess4typ==4)&&(data.prozess3typ==5))
        %4 ... adiabatisch, 3 ... polytrop
        func=@(x) hpolyt(V3,x,p3)-hadiab(V5,x,p5);
        Vvek=sort([V3,V5]);
        Vvek=[Vvek(1)/data.umgebung,Vvek(2)*data.umgebung];
        try
        [V4best, fval, fehlerzero]=fzero(func,Vvek);
        catch errorcatch
            data.errorcatch=errorcatch;
            fehlerzero=-0.5;
            V4best=(V3+V5)/2;
        end
        %Berechnung der Werte fuer den Schnittpunkt
        [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,3,V4best,points );
        [T4a,p4a,V4a,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T5,p5,V5,gam,3,V4best,points );
        weg1=true;
        weg2=true;
    end
end

if (fehlerzero<0)
    Auswahlcell{1}='isotherm';
    Auswahlcell{2}='isobar';
    Auswahlcell{3}='isochor';
    
    ausg=['Waehlen Sie     ';'bitte einen     ';' zusaetzlichen  ' ; 'Prozessschritt :'];
    okbutton=100;
    while (okbutton~=1)
    [zusatzschritt, okbutton]=listdlg('liststring',Auswahlcell,...
           'promptstring',ausg,...
           'name','Es geht sich nicht aus',...
           'selectionmode','single');
    end
    switch zusatzschritt
        case 1 %isotherm
         if ((data.prozess3typ==4)&&(data.prozess4typ==5))
            V4best=(V3+V5)/2;
            %3 ... adiabatisch, 4 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T4,p4,V4,kap,cv,zusatzschritt,T1,points ); 
         end
         if ((data.prozess4typ==4)&&(data.prozess3typ==5))
            V4best=(V3+V5)/2;
            %4 ... adiabatisch, 3 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T4,p4,V4,gam,zusatzschritt,T1,points );
         end
            [T6,p6,V6,dU5,dW5,dQ5,dS5,pv5,Vv5,Sv5,Tv5]=...
                isoth(T5,p5,V5,2,p1,points);
            
            
        case 2 %isobar
         if ((data.prozess3typ==4)&&(data.prozess4typ==5))
            V4best=(V3+V5)/2;
            %3 ... adiabatisch, 4 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T4,p4,V4,kap,cv,zusatzschritt,p1,points ); 
         end
         if ((data.prozess4typ==4)&&(data.prozess3typ==5))
            V4best=(V3+V5)/2;
            %4 ... adiabatisch, 3 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T4,p4,V4,gam,zusatzschritt,p1,points );
         end
         [T6,p6,V6,dU5,dW5,dQ5,dS5,pv5,Vv5,Sv5,Tv5]=...
                isob(T5,p5,V5,cp,1,T1,points );
            
            
        case 3 %isochor
         if ((data.prozess3typ==4)&&(data.prozess4typ==5))
            V4best=(V3+V5)/2;
            %3 ... adiabatisch, 4 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                adiab(T3,p3,V3,gam,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                poly(T4,p4,V4,kap,cv,zusatzschritt,V1,points ); 
         end
         if ((data.prozess4typ==4)&&(data.prozess3typ==5))
            V4best=(V3+V5)/2;
            %4 ... adiabatisch, 3 ... polytrop
            [T4,p4,V4,dU3,dW3,dQ3,dS3,pv3,Vv3,Sv3,Tv3]=...
                poly(T3,p3,V3,kap,cv,3,V4best,points );
            [T5,p5,V5,dU4,dW4,dQ4,dS4,pv4,Vv4,Sv4,Tv4]=...
                adiab(T4,p4,V4,gam,zusatzschritt,V1,points );
         end
         [T6,p6,V6,dU5,dW5,dQ5,dS5,pv5,Vv5,Sv5,Tv5]=...
                isochor(T5,p5,V5,cv,1,T1,points );
    end

    
end
if(not(weg1) || not(weg2))
    error('fehlerhafte Berechnung');
end

%%%%%%%%%%%% Transformieren zur Ausgabe

%__________________________Transformation Skalare
if (fehlerzero>=0)
    dT=(T4-T4a)/T4;
    dp=(p4-p4a)/p4;
    dV=(V4-V4a)/V4;

    pv4=fliplr(pv4);
    Vv4=fliplr(Vv4);
    Sv4=fliplr(Sv4);
    Tv4=fliplr(Tv4);

    dU4=-dU4;
    dW4=-dW4;
    dQ4=-dQ4;
    dS4=-dS4;
else
    dT=(T1-T6)/T1;
    dp=(p1-p6)/p1;
    dV=(V1-V6)/V1;
end

%________________________Transformation Vektoren
if (fehlerzero>=0)
    data.Sv1=Sv1;
    data.Tv1=Tv1;
    Sv2=Sv1(end)+Sv2;
    data.Sv2=Sv2;
    data.Tv2=Tv2;
    Sv3=Sv2(end)+Sv3;
    data.Sv3=Sv3;
    data.Tv3=Tv3;
    Sv4=Sv3(end)+Sv4-Sv4(1);
    data.Sv4=Sv4;
    data.Tv4=Tv4;
    
    %Aenderung der Entropie
    dS=Sv4(end);
else
    data.Sv1=Sv1;
    data.Tv1=Tv1;
    Sv2=Sv1(end)+Sv2;
    data.Sv2=Sv2;
    data.Tv2=Tv2;
    Sv3=Sv2(end)+Sv3;
    data.Sv3=Sv3;
    data.Tv3=Tv3;
    Sv4=Sv3(end)+Sv4;
    data.Sv4=Sv4;
    data.Tv4=Tv4;
    Sv5=Sv4(end)+Sv5;
    data.Sv5=Sv5;
    data.Tv5=Tv5;
    %Aenderung der Entropie
    dS=Sv5(end);
end

%Ausgabe der Abweichung vom Startpunkt
%ausg=['dT=',num2str(dT),'  dp=',num2str(dp),'   dV=',num2str(dV),'   dS=',num2str(dS)];
%disp(ausg);

%%%%%%%%%%%%%%%%%%%%%%% Aktualisierung der Diagramme

%_________________________________________pV-Darstellung
set(data.pV_diagramm,'visible','on');
set(data.pV_plot1,'xdata',Vv1,'ydata',pv1);
set(data.pV_plot2,'xdata',Vv2,'ydata',pv2);
set(data.pV_plot3,'xdata',Vv3,'ydata',pv3);
set(data.pV_plot4,'xdata',Vv4,'ydata',pv4);

if (fehlerzero<0)
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt','5.Schritt'};
    set(data.pV_plot5,'xdata',Vv5,'ydata',pv5,'visible','on');
else
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt'};
    set(data.pV_plot5,'visible','off');
end
set(data.pV_legend,'string',ausg);

%_____________________________________________________________TS - Diagramm

set(data.TS_diagramm,'visible','on');
set(data.TS_plot1,'xdata',Sv1,'ydata',Tv1);
set(data.TS_plot2,'xdata',Sv2,'ydata',Tv2);
set(data.TS_plot3,'xdata',Sv3,'ydata',Tv3);
set(data.TS_plot4,'xdata',Sv4,'ydata',Tv4);

if (fehlerzero<0)
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt','5.Schritt'};
    set(data.TS_plot5,'xdata',Sv5,'ydata',Tv5,'visible','on');
else
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt'};
    set(data.TS_plot5,'visible','off');
end
set(data.TS_legend,'string',ausg);

%_________________________________________________________________________3D-plot
set(data.D3_diagramm,'visible','on');
set(data.D3_plot1,'xdata',pv1,'ydata',Vv1,'zdata',Tv1);
set(data.D3_plot2,'xdata',pv2,'ydata',Vv2,'zdata',Tv2);
set(data.D3_plot3,'xdata',pv3,'ydata',Vv3,'zdata',Tv3);
set(data.D3_plot4,'xdata',pv4,'ydata',Vv4,'zdata',Tv4);


if (fehlerzero<0) 
    set(data.D3_plot5,'xdata',pv5,'ydata',Vv5,'zdata',Tv5,'visible','on');
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt','5.Schritt'};
else
    ausg={'1.Schritt','2.Schritt','3.Schritt','4.Schritt'};
    set(data.D3_plot5,'visible','off');
end
set(data.D3_legend,'string',ausg);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Speichern
if (fehlerzero>=0)
    Tvek=[T1,T2,T3,T4,T5];
    data.Tvek=Tvek;
    pvek=[p1,p2,p3,p4,p5];
    data.pvek=pvek;
    Vvek=[V1,V2,V3,V4,V5];
    data.Vvek=Vvek;

    dUvek=[dU1,dU2,dU3,dU4];
    dUvek=[dUvek,sum(dUvek)];
    data.dUvek=dUvek;

    dWvek=[dW1,dW2,dW3,dW4];
    dWvek=[dWvek,sum(dWvek)];
    data.dWvek=dWvek;

    dQvek=[dQ1,dQ2,dQ3,dQ4];
    dQvek=[dQvek,sum(dQvek)];
    data.dQvek=dQvek;

    dSvek=[dS1,dS2,dS3,dS4];
    dSvek=[dSvek,sum(dSvek)];
    data.dSvek=dSvek;
else  
    Tvek=[T1,T2,T3,T4,T5,T6];
    data.Tvek=Tvek;
    pvek=[p1,p2,p3,p4,p5,p6];
    data.pvek=pvek;
    Vvek=[V1,V2,V3,V4,V5,V6];
    data.Vvek=Vvek;

    dUvek=[dU1,dU2,dU3,dU4,dU5];
    dUvek=[dUvek,sum(dUvek)];
    data.dUvek=dUvek;

    dWvek=[dW1,dW2,dW3,dW4,dW5];
    dWvek=[dWvek,sum(dWvek)];
    data.dWvek=dWvek;

    dQvek=[dQ1,dQ2,dQ3,dQ4,dQ5];
    dQvek=[dQvek,sum(dQvek)];
    data.dQvek=dQvek;

    dSvek=[dS1,dS2,dS3,dS4,dS5];
    dSvek=[dSvek,sum(dSvek)];
    data.dSvek=dSvek;
end


%%%%%%%%%%%%%%%%%%%%%%%%%% Tabellen -Ausgabe
if (fehlerzero>=0)
  %TS-Tabelle
    dbox=ceil((data.boxweite_TS-40)/5);
    set(data.TS_tabelle,'columnwidth', {dbox,dbox,dbox,dbox,dbox});
    Spalten=[' 1  ';' 2  ';' 3  ';' 4  ';'Ges.'];
    set(data.TS_tabelle,'columnname',Spalten);
    Mat=[dUvek;dWvek;dQvek;dSvek];
    set(data.TS_tabelle,'data',Mat);
  %pV-Tabelle
    dbox=round((data.boxweite_pV-50)/5);
    set(data.pV_tabelle,'columnwidth', {dbox,dbox,dbox,dbox,dbox});
    Mat1=[pvek;Vvek;Tvek];
    set(data.pV_tabelle,'data',Mat1);
  %D3 -Tabelle
    dbox=data.boxweite_D3/3;
    set(data.D3_tabelle,'columnwidth', {dbox,dbox,dbox});
    Arbeit=dWvek(end);
    Waerme=sum(dQvek(1:end-1).*heaviside(dQvek(1:end-1)));
    Wirkungsgrad=-Arbeit/Waerme;
    Mat2=[Arbeit,Waerme,Wirkungsgrad];
    set(data.D3_tabelle,'data',Mat2);

else
  %TS-Tabelle
    dbox=ceil((data.boxweite_TS-30)/6);
    set(data.TS_tabelle,'columnwidth', {dbox,dbox,dbox,dbox,dbox,dbox});
    Spalten=[' 1  ';' 2  ';' 3  ';' 4  ';' 5  ';'Ges.'];
    set(data.TS_tabelle,'columnname',Spalten);
    Mat=[dUvek;dWvek;dQvek;dSvek];
    set(data.TS_tabelle,'data',Mat);
  %pV-Tabelle
    dbox=round((data.boxweite_pV-50)/6);
    set(data.pV_tabelle,'columnwidth', {dbox,dbox,dbox,dbox,dbox,dbox});
    Mat1=[pvek;Vvek;Tvek];
    set(data.pV_tabelle,'data',Mat1);
   %D3 -Tabelle
    dbox=data.boxweite_D3/3;
    set(data.D3_tabelle,'columnwidth', {dbox,dbox,dbox});
    Arbeit=dWvek(end);
    Waerme=sum(dQvek(1:end-1).*heaviside(dQvek(1:end-1)));
    Wirkungsgrad=-Arbeit/Waerme;
    Mat2=[Arbeit,Waerme,Wirkungsgrad];
    set(data.D3_tabelle,'data',Mat2);
end

if((abs(dS)-10^-10)>0)
    data.S_error=errordlg('Entropieabnahme');
end

set(data.prozess_but,'visible','on');
set(data.Kreisprozess_button,'visible','off');

%Checkboxes aktiv setzen
set(data.prozess1_isotherm,'enable','on');
set(data.prozess1_isobar,'enable','on');
set(data.prozess1_isochor,'enable','on');
set(data.prozess1_adiabatisch,'enable','on');
set(data.prozess1_polytrop,'enable','on');

set(data.prozess2_isotherm,'enable','on');
set(data.prozess2_isobar,'enable','on');
set(data.prozess2_isochor,'enable','on');
set(data.prozess2_adiabatisch,'enable','on');
set(data.prozess2_polytrop,'enable','on');

set(data.prozess3_isotherm,'enable','on');
set(data.prozess3_isobar,'enable','on');
set(data.prozess3_isochor,'enable','on');
set(data.prozess3_adiabatisch,'enable','on');
set(data.prozess3_polytrop,'enable','on');

set(data.prozess4_isotherm,'enable','on');
set(data.prozess4_isobar,'enable','on');
set(data.prozess4_isochor,'enable','on');
set(data.prozess4_adiabatisch,'enable','on');
set(data.prozess4_polytrop,'enable','on');
end

